%define realname        zstd
%define libmajor        1
%define libname         %mklibname %{realname} %{libmajor}
%define libname_devel   %mklibname %{realname} -d

%ifarch %{ix86} x86_64
%bcond_without pzstd
%else
# aarch64 and armv7hl at least currently segfault
# in ThreadPool test for the pzstd util
%bcond_with pzstd
%endif

# Something is broken with how Iurt sets up the environment
# for the test suite's run...
%bcond_without check

Name:           zstd
Version:        1.4.8
%define subrel	2
Release:        %mkrel 1
Summary:        Zstd compression library
Group:          Archiving/Compression
License:        BSD and GPLv2
URL:            http://www.zstd.net/
Source0:        https://github.com/facebook/zstd/archive/v%{version}/%{name}-%{version}.tar.gz
Patch1:         pzstd.1.patch
Patch2:         0018-fix-file-permissions-on-compression.patch
# CVE-2022-4899 https://github.com/facebook/zstd/pull/3220
Patch3:         Disallow-empty-output-directory.patch
Patch4:         Fix-buffer-underflow-for-null-dir1.patch

BuildRequires:  pkgconfig(gtest)
BuildRequires:  pkgconfig(liblzma)

%description
Zstd, short for Zstandard, is a fast lossless compression algorithm,
targeting real-time compression scenarios at zlib-level compression ratio.

%package -n %{libname}
Summary:        Zstd shared library
Group:          System/Libraries
%description -n %{libname}
Zstandard compression shared library.

%package -n %{libname_devel}
Summary:        Header files for Zstd library
Group:          Development/C
Requires:       %{libname} = %{version}-%{release}
Provides:       %{name}-devel = %{version}-%{release}
Provides:       lib%{name}-devel = %{version}-%{release}

%description -n %{libname_devel}
Header files for Zstd library.


%prep
%setup -q
find -name .gitignore -delete
%if %{with pzstd}
%patch1 -p1
%endif
%patch2 -p1
%patch3 -p1
%patch4 -p1

%build
%set_build_flags
%make_build -C lib lib-mt
%make_build -C programs
%if %{with pzstd}
%make_build -C contrib/pzstd
%endif

%if %{with check}
%check
make -C tests test-zstd
%if %{with pzstd}
make -C contrib/pzstd test
%endif
%endif

%install
%make_install PREFIX=%{_prefix} LIBDIR=%{_libdir}
# Don't install the static lib
rm %{buildroot}/%{_libdir}/libzstd.a
%if %{with pzstd}
install -D -m755 contrib/pzstd/pzstd %{buildroot}%{_bindir}/pzstd
install -D -m644 programs/%{name}.1 %{buildroot}%{_mandir}/man1/p%{name}.1
%endif

%files
%doc CHANGELOG README.md
%{_bindir}/%{name}
%if %{with pzstd}
%{_bindir}/p%{name}
%{_mandir}/man1/p%{name}.1*
%endif
%{_bindir}/%{name}mt
%{_bindir}/un%{name}
%{_bindir}/%{name}cat
%{_bindir}/%{name}grep
%{_bindir}/%{name}less
%{_mandir}/man1/%{name}.1*
%{_mandir}/man1/un%{name}.1*
%{_mandir}/man1/%{name}cat.1*
%{_mandir}/man1/%{name}grep.1*
%{_mandir}/man1/%{name}less.1*
%license LICENSE

%files -n %{libname}
%{_libdir}/libzstd.so.%{libmajor}{,.*}
%license LICENSE

%files -n %{libname_devel}
%{_includedir}/zdict.h
%{_includedir}/zstd.h
%{_includedir}/zstd_errors.h
%{_libdir}/pkgconfig/libzstd.pc
%{_libdir}/libzstd.so


%changelog
* Fri Mar 31 2023 daviddavid <daviddavid> 1.4.8-1.2.mga8
+ Revision: 1950986
- add upstream patches to fix CVE-2022-4899 (mga#31740)
+ luigiwalser <luigiwalser>
- add patch from debian to fix CVE-2021-24032

* Tue Dec 22 2020 daviddavid <daviddavid> 1.4.8-1.mga8
+ Revision: 1662830
- new version: 1.4.8

* Fri Dec 18 2020 tv <tv> 1.4.7-2.mga8
+ Revision: 1660959
- Fix alignment of scratchBuffer in HUF_compressWeights()

* Thu Dec 17 2020 tv <tv> 1.4.7-1.mga8
+ Revision: 1660447
- 1.4.7

* Wed Oct 14 2020 tv <tv> 1.4.5-4.mga8
+ Revision: 1636094
- try to re-enable the testsuite on BS

* Wed Jul 15 2020 tv <tv> 1.4.5-3.mga8
+ Revision: 1606372
- Build libzstd with multi-threading support

* Mon May 25 2020 tv <tv> 1.4.5-2.mga8
+ Revision: 1587625
- Build shared library with correct compiler flags

* Sat May 23 2020 tv <tv> 1.4.5-1.mga8
+ Revision: 1587135
- 1.4.5

* Sat May 02 2020 tv <tv> 1.4.4-3.mga8
+ Revision: 1577907
- enable to uncompress lzma files too

* Tue Feb 18 2020 umeabot <umeabot> 1.4.4-2.mga8
+ Revision: 1539494
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%setup_compile_flags

* Sun Dec 08 2019 daviddavid <daviddavid> 1.4.4-1.mga8
+ Revision: 1465151
- new version: 1.4.4

* Sun Sep 08 2019 wally <wally> 1.4.3-1.mga8
+ Revision: 1438475
- new version 1.4.3

* Sat Jul 20 2019 akien <akien> 1.4.1-1.mga8
+ Revision: 1423213
- Version 1.4.1

* Thu Apr 18 2019 akien <akien> 1.4.0-1.mga7
+ Revision: 1393195
- Version 1.4.0

* Tue Jan 01 2019 luigiwalser <luigiwalser> 1.3.8-1.mga7
+ Revision: 1347826
- 1.3.8

* Sun Oct 28 2018 ngompa <ngompa> 1.3.7-1.mga7
+ Revision: 1326305
- Update to 1.3.7

* Sun Sep 23 2018 umeabot <umeabot> 1.3.5-2.mga7
+ Revision: 1302067
- Mageia 7 Mass Rebuild

* Thu Aug 09 2018 ngompa <ngompa> 1.3.5-1.mga7
+ Revision: 1250680
- Disable automatic runs of zstd test suite for now...
- Update to 1.3.5

* Wed Apr 25 2018 ngompa <ngompa> 1.3.4-1.mga7
+ Revision: 1222353
- Update to 1.3.4
- Refresh pzstd patch from Fedora
- Use bcond for pzstd conditional

* Tue Nov 21 2017 tmb <tmb> 1.3.2-1.mga7
+ Revision: 1178202
- fix group
- adapt for Mageia
- import from fedora


* Fri Nov 10 2017 Pádraig Brady <P@draigBrady.com> - 1.3.2-1
- Latest upstream

* Mon Aug 21 2017 Pádraig Brady <P@draigBrady.com> - 1.3.1-1
- Latest upstream

* Thu Aug 03 2017 Fedora Release Engineering <releng@fedoraproject.org> - 1.3.0-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Binutils_Mass_Rebuild

* Thu Jul 27 2017 Fedora Release Engineering <releng@fedoraproject.org> - 1.3.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Sun Jul 16 2017 Pádraig Brady <P@draigBrady.com> - 1.3.0-1
- Latest upstream

* Mon May 08 2017 Pádraig Brady <P@draigBrady.com> - 1.2.0-1
- Latest upstream

* Mon Mar 06 2017 Pádraig Brady <P@draigBrady.com> - 1.1.3-1
- Latest upstream

* Sat Feb 11 2017 Fedora Release Engineering <releng@fedoraproject.org> - 1.1.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Wed Nov 02 2016 Pádraig Brady <pbrady@redhat.com> - 1.1.1-1
- Latest upstream

* Thu Oct 6  2016 Pádraig Brady <pbrady@fb.com> 1.1.0-2
- Add pzstd(1)

* Thu Sep 29 2016 Pádraig Brady <pbrady@fb.com> 1.1.0-1
- New upstream release
- Remove examples and static lib

* Mon Sep 12 2016 Pádraig Brady <pbrady@fb.com> 1.0.0-2
- Adjust various upstream links
- Parameterize various items in spec file

* Mon Sep 5 2016 Pádraig Brady <pbrady@fb.com> 1.0.0-1
- Initial release
